#!/usr/bin/env python
# -*- coding:  utf-8 -*-
"""
commandor.exceptions
~~~~~~~~~~~~~~~~~~~

Commandor library exceptions

:copyright: (c) 2012 by Alexandr Lispython (alex@obout.ru).
:license: BSD, see LICENSE for more details.
:github: http://github.com/Lispython/commandor
"""

class InvalidCommand(Exception):
    """Invalid console command
    """

class InvalidScriptOption(Exception):
    """Invalid script option
    """

class InvalidCommandOption(Exception):
    """InvalidCommandOption
    """
